@@ -1,32 +1,49 @@
 import logging
 import os
 from getpass import getpass
+from hashlib import md5
 
 import click
 
+from .clients import TidalClient
 from .config import Config
 from .constants import CACHE_DIR, CONFIG_DIR, CONFIG_PATH, QOBUZ_FEATURED_KEYS
 from .core import MusicDL
 from .utils import init_log
 
 logger = logging.getLogger(__name__)
-config = Config(CONFIG_PATH)
 
 if not os.path.isdir(CONFIG_DIR):
-    os.makedirs(CONFIG_DIR)
+    os.makedirs(CONFIG_DIR, exist_ok=True)
 if not os.path.isdir(CACHE_DIR):
-    os.makedirs(CONFIG_DIR)
+    os.makedirs(CONFIG_DIR, exist_ok=True)
 
 
 @click.group(invoke_without_command=True)
-@click.option("-c", "--convert", metavar="CODEC")
-@click.option("-u", "--urls", metavar="URLS")
+@click.option("-c", "--convert", metavar="CODEC", help="alac, mp3, flac, or ogg")
+@click.option("-u", "--urls", metavar="URLS", help="Url from Qobuz, Tidal, or Deezer")
+@click.option(
+    "-q",
+    "--quality",
+    metavar="INT",
+    help="0: < 320kbps, 1: 320 kbps, 2: 16 bit/44.1 kHz, 3: 24 bit/<=96 kHz, 4: 24 bit/<=192 kHz",
+)
 @click.option("-t", "--text", metavar="PATH")
 @click.option("-nd", "--no-db", is_flag=True)
 @click.option("--debug", is_flag=True)
 @click.pass_context
 def cli(ctx, **kwargs):
-    """"""
+    """Streamrip: The all-in-one Qobuz, Tidal, and Deezer music downloader.
+
+    To get started, try:
+
+        $ rip -u https://www.deezer.com/en/album/6612814
+
+    For customization down to the details, see the config file:
+
+        $ rip config --open
+
+    """
     global config
     global core
 
@@ -40,6 +57,15 @@ def cli(ctx, **kwargs):
     if kwargs["convert"]:
         config.session["conversion"]["enabled"] = True
         config.session["conversion"]["codec"] = kwargs["convert"]
+    if kwargs["quality"] is not None:
+        quality = int(kwargs["quality"])
+        if quality not in range(5):
+            click.secho("Invalid quality", fg="red")
+            return
+
+        config.session["qobuz"]["quality"] = quality
+        config.session["tidal"]["quality"] = quality
+        config.session["deezer"]["quality"] = quality
 
     core = MusicDL(config)
 
@@ -78,7 +104,7 @@ def filter_discography(ctx, **kwargs):
     """
 
     filters = kwargs.copy()
-    filters.remove("urls")
+    filters.pop("urls")
     config.session["filters"] = filters
     logger.debug(f"downloading {kwargs['urls']} with filters {filters}")
     core.handle_urls(" ".join(kwargs["urls"]))
@@ -172,34 +198,40 @@ def discover(ctx, **kwargs):
 @cli.command()
 @click.option("-o", "--open", is_flag=True, help="Open the config file")
 @click.option("-q", "--qobuz", is_flag=True, help="Set Qobuz credentials")
+@click.option("-t", "--tidal", is_flag=True, help="Re-login into Tidal")
 @click.option("--reset", is_flag=True, help="RESET the config file")
 @click.pass_context
 def config(ctx, **kwargs):
-    """Manage the streamrip configuration."""
+    """Manage the streamrip configuration file."""
     if kwargs["reset"]:
         config.reset()
 
     if kwargs["open"]:
+        click.secho(f"Opening {CONFIG_PATH}", fg="green")
         click.launch(CONFIG_PATH)
 
     if kwargs["qobuz"]:
-        config.file["qobuz"]["email"] = input("Qobuz email: ")
-        config.file["qobuz"]["password"] = getpass()
+        config.file["qobuz"]["email"] = input(click.style("Qobuz email: ", fg="blue"))
+
+        click.secho("Qobuz password (will not show on screen):", fg="blue")
+        config.file["qobuz"]["password"] = md5(
+            getpass(prompt="").encode("utf-8")
+        ).hexdigest()
+
         config.save()
+        click.secho("Qobuz credentials hashed and saved to config.", fg="green")
+
+    if kwargs["tidal"]:
+        client = TidalClient()
+        client.login()
+        config.file["tidal"].update(client.get_tokens())
+        config.save()
+        click.secho("Credentials saved to config.", fg="green")
 
 
 def none_chosen():
     click.secho("No items chosen, exiting.", fg="bright_red")
 
 
-def parse_urls(arg: str):
-    if os.path.isfile(arg):
-        return arg, "txt"
-    if "http" in arg:
-        return arg, "urls"
-
-    raise ValueError(f"Invalid argument {arg}")
-
-
 def main():
     cli(obj={})
