@@ -1,12 +1,17 @@
 import copy
 import logging
 import os
-from pathlib import Path
 from pprint import pformat
 
 from ruamel.yaml import YAML
 
-from .constants import CONFIG_PATH, DOWNLOADS_DIR, FOLDER_FORMAT, TRACK_FORMAT
+from .constants import (
+    CONFIG_DIR,
+    CONFIG_PATH,
+    DOWNLOADS_DIR,
+    FOLDER_FORMAT,
+    TRACK_FORMAT,
+)
 from .exceptions import InvalidSourceError
 
 yaml = YAML()
@@ -49,6 +54,9 @@ class Config:
         "deezer": {
             "quality": 2,
         },
+        "soundcloud": {
+            "quality": 0,
+        },
         "database": {"enabled": True, "path": None},
         "conversion": {
             "enabled": False,
@@ -67,7 +75,7 @@ class Config:
         "downloads": {"folder": DOWNLOADS_DIR},
         "metadata": {
             "embed_cover": True,
-            "large_cover": False,
+            "large_cover": True,
             "default_comment": None,
             "remove_extra_tags": False,
         },
@@ -95,6 +103,9 @@ class Config:
         self.dump(self.file)
 
     def reset(self):
+        if not os.path.isdir(CONFIG_DIR):
+            os.makedirs(CONFIG_DIR, exist_ok=True)
+
         self.dump(self.defaults)
 
     def load(self):
