@@ -19,6 +19,7 @@ AGENT = "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:83.0) Gecko/20100101 Firef
 TIDAL_COVER_URL = "https://resources.tidal.com/images/{uuid}/{width}x{height}.jpg"
 
 EXT = {
+    0: ".mp3",
     1: ".mp3",
     2: ".flac",
     3: ".flac",
@@ -71,6 +72,7 @@ __MP4_KEYS = (
     "covr",
     "trkn",
     "disk",
+    None,
 )
 
 __MP3_KEYS = (
@@ -92,6 +94,7 @@ __MP3_KEYS = (
     None,
     id3.TRCK,
     id3.TPOS,
+    None,
 )
 
 __METADATA_TYPES = (
@@ -113,6 +116,7 @@ __METADATA_TYPES = (
     "cover",
     "tracknumber",
     "discnumber",
+    "tracktotal",
 )
 
 
@@ -124,19 +128,24 @@ COPYRIGHT = "\u2117"
 PHON_COPYRIGHT = "\u00a9"
 FLAC_MAX_BLOCKSIZE = 16777215  # 16.7 MB
 
+# TODO: give these more descriptive names
 TRACK_KEYS = ("tracknumber", "artist", "albumartist", "composer", "title")
 ALBUM_KEYS = ("albumartist", "title", "year", "bit_depth", "sampling_rate", "container")
+# TODO: rename these to DEFAULT_FOLDER_FORMAT etc
 FOLDER_FORMAT = (
     "{albumartist} - {title} ({year}) [{container}] [{bit_depth}B-{sampling_rate}kHz]"
 )
 TRACK_FORMAT = "{tracknumber}. {artist} - {title}"
 
 URL_REGEX = (
-    r"https:\/\/(?:www|open|play|listen)?\.?(\w+)\.com(?:(?:\/(track|playlist|album|"
+    r"https:\/\/(?:www|open|play|listen)?\.?(qobuz|tidal|deezer)\.com(?:(?:\/(track|playlist|album|"
     r"artist|label))|(?:\/[-\w]+?))+\/([-\w]+)"
 )
+SOUNDCLOUD_URL_REGEX = r"https://soundcloud.com/[-\w:/]+"
+SOUNDCLOUD_CLIENT_ID = "a3e059563d7fd3372b49b37f00a00bcf"
 
 
 TIDAL_MAX_Q = 7
 DEEZER_MAX_Q = 6
 AVAILABLE_QUALITY_IDS = (0, 1, 2, 3, 4)
+MEDIA_TYPES = ("track", "album", "artist", "label", "playlist")
