@@ -37,6 +37,7 @@ class MusicDB:
         :type item_id: str
         :rtype: bool
         """
+        logger.debug(f"Checking database for ID {item_id}")
         with sqlite3.connect(self.path) as conn:
             return (
                 conn.execute(
@@ -51,6 +52,7 @@ class MusicDB:
         :param item_id:
         :type item_id: str
         """
+        logger.debug(f"Adding ID {item_id}")
         with sqlite3.connect(self.path) as conn:
             try:
                 conn.execute(
@@ -58,5 +60,6 @@ class MusicDB:
                     (item_id,),
                 )
                 conn.commit()
-            except sqlite3.Error as error:
-                logger.error("Unexpected DB error: %s", error)
+            except sqlite3.Error as e:
+                if "UNIQUE" not in str(e):
+                    raise
