@@ -1,10 +1,10 @@
 import logging
+import sys
 import os
 import re
 import shutil
-# import sys
-from pprint import pformat
-# from pprint import pprint
+import subprocess
+from pprint import pformat, pprint
 from tempfile import gettempdir
 from typing import Any, Callable, Optional, Tuple, Union
 
@@ -93,13 +93,12 @@ class Track:
         self.__dict__.update(kwargs)
 
         # adjustments after blind attribute sets
-        self.file_format = kwargs.get("track_format", TRACK_FORMAT)
         self.container = "FLAC"
         self.sampling_rate = 44100
         self.bit_depth = 16
 
-        self._is_downloaded = False
-        self._is_tagged = False
+        self.downloaded = False
+        self.tagged = False
         for attr in ("quality", "folder", "meta"):
             setattr(self, attr, None)
 
@@ -119,17 +118,21 @@ class Track:
 
         assert hasattr(self, "id"), "id must be set before loading metadata"
 
-        track_meta = self.client.get(self.id, media_type="track")
+        self.resp = self.client.get(self.id, media_type="track")
         self.meta = TrackMetadata(
-            track=track_meta, source=self.client.source
+            track=self.resp, source=self.client.source
         )  # meta dict -> TrackMetadata object
         try:
             if self.client.source == "qobuz":
-                self.cover_url = track_meta["album"]["image"]["small"]
+                self.cover_url = self.resp["album"]["image"]["small"]
             elif self.client.source == "tidal":
-                self.cover_url = tidal_cover_url(track_meta["album"]["cover"], 320)
+                self.cover_url = tidal_cover_url(self.resp["album"]["cover"], 320)
             elif self.client.source == "deezer":
-                self.cover_url = track_meta["album"]["cover_medium"]
+                self.cover_url = self.resp["album"]["cover_medium"]
+            elif self.client.source == "soundcloud":
+                self.cover_url = (
+                    self.resp["artwork_url"] or self.resp["user"].get("avatar_url")
+                ).replace("large", "t500x500")
             else:
                 raise InvalidSourceError(self.client.source)
         except KeyError:
@@ -147,52 +150,60 @@ class Track:
 
     def download(
         self,
-        quality: int = 7,
-        parent_folder: str = "Downloads",
+        quality: int = 3,
+        parent_folder: str = "StreamripDownloads",
         progress_bar: bool = True,
         database: MusicDB = None,
         tag: bool = False,
+        **kwargs,
     ):
         """
         Download the track.
 
-        :param quality: (5, 6, 7, 27)
+        :param quality: (0, 1, 2, 3, 4)
         :type quality: int
         :param folder: folder to download the files to
         :type folder: Optional[Union[str, os.PathLike]]
         :param progress_bar: turn on/off progress bar
         :type progress_bar: bool
         """
-        self.quality, self.folder = (
-            quality or self.quality,
-            parent_folder or self.folder,
-        )
-        self.folder = sanitize_filepath(parent_folder, platform="auto")
+        # args override attributes
+        self.quality = min(quality, self.client.max_quality)
+        self.folder = parent_folder or self.folder
+
+        self.file_format = kwargs.get("track_format", TRACK_FORMAT)
+        self.folder = sanitize_filepath(self.folder, platform="auto")
 
         os.makedirs(self.folder, exist_ok=True)
 
         if database is not None:
             if self.id in database:
-                self._is_downloaded = True
-                self._is_tagged = True
+                self.downloaded = True
+                self.tagged = True
                 click.secho(
                     f"{self['title']} already logged in database, skipping.",
                     fg="magenta",
                 )
-                return
+                return False  # because the track was not downloaded
 
-        if os.path.isfile(self.format_final_path()):
-            self._is_downloaded = True
-            self._is_tagged = True
+        if os.path.isfile(self.format_final_path()):  # track already exists
+            self.downloaded = True
+            self.tagged = True
             click.secho(f"Track already downloaded: {self.final_path}", fg="magenta")
             return False
 
-        if hasattr(self, "cover_url"):
+        if hasattr(self, "cover_url"):  # only for playlists and singles
+            logger.debug("Downloading cover")
             self.download_cover()
 
-        dl_info = self.client.get_file_url(self.id, quality)  # dict
+        if self.client.source == "soundcloud":
+            url_id = self.resp
+        else:
+            url_id = self.id
 
-        temp_file = os.path.join(gettempdir(), f"~{self.id}_{quality}.tmp")
+        dl_info = self.client.get_file_url(url_id, self.quality)
+
+        temp_file = os.path.join(gettempdir(), f"~{hash(self.id)}_{quality}.tmp")
         logger.debug("Temporary file path: %s", temp_file)
 
         if self.client.source == "qobuz":
@@ -206,17 +217,13 @@ class Track:
             self.sampling_rate = dl_info.get("sampling_rate")
             self.bit_depth = dl_info.get("bit_depth")
 
-        if os.path.isfile(temp_file):
-            logger.debug("Temporary file found: %s", temp_file)
-            self._is_downloaded = True
-            self._is_tagged = False
-
         click.secho(f"\nDownloading {self!s}", fg="blue")
 
         if self.client.source in ("qobuz", "tidal"):
             logger.debug("Downloadable URL found: %s", dl_info.get("url"))
             tqdm_download(dl_info["url"], temp_file)  # downloads file
-        elif isinstance(dl_info, str):  # Deezer
+
+        elif self.client.source == "deezer":  # Deezer
             logger.debug("Downloadable URL found: %s", dl_info)
             try:
                 tqdm_download(dl_info, temp_file)  # downloads file
@@ -224,6 +231,10 @@ class Track:
                 logger.debug(f"Track is not downloadable {dl_info}")
                 click.secho("Track is not available for download", fg="red")
                 return False
+
+        elif self.client.source == "soundcloud":
+            temp_file = self._soundcloud_download(dl_info, temp_file)
+
         else:
             raise InvalidSourceError(self.client.source)
 
@@ -238,28 +249,60 @@ class Track:
 
         logger.debug("Downloaded: %s -> %s", temp_file, self.final_path)
 
-        self._is_downloaded = True
+        self.downloaded = True
 
         if tag:
             self.tag()
 
+        if not kwargs.get("keep_cover", True) and hasattr(self, "cover_path"):
+            os.remove(self.cover_path)
+
         return True
 
+    def _soundcloud_download(self, dl_info: dict, temp_file: str) -> str:
+        if dl_info["type"] == "mp3":
+            temp_file += ".mp3"
+            # convert hls stream to mp3
+            subprocess.call(
+                [
+                    "ffmpeg",
+                    "-i",
+                    dl_info["url"],
+                    "-c",
+                    "copy",
+                    "-y",
+                    temp_file,
+                    "-loglevel",
+                    "fatal",
+                ]
+            )
+        elif dl_info["type"] == "original":
+            tqdm_download(dl_info["url"], temp_file)
+
+            # if a wav is returned, convert to flac
+            engine = converter.FLAC(temp_file)
+            temp_file = f"{temp_file}.flac"
+            engine.convert(custom_fn=temp_file)
+
+            self.final_path = self.final_path.replace(".mp3", ".flac")
+            self.quality = 2
+
+        return temp_file
+
     def download_cover(self):
         """Downloads the cover art, if cover_url is given."""
 
-        assert hasattr(self, "cover_url"), "must pass cover_url parameter"
+        assert hasattr(self, "cover_url"), "must set cover_url attribute"
 
-        self.cover_path = os.path.join(self.folder, f"cover{hash(self.id)}.jpg")
+        self.cover_path = os.path.join(self.folder, f"cover{hash(self.cover_url)}.jpg")
         logger.debug(f"Downloading cover from {self.cover_url}")
+        click.secho(f"\nDownloading cover art for {self!s}", fg="blue")
+
         if not os.path.exists(self.cover_path):
             tqdm_download(self.cover_url, self.cover_path)
         else:
             logger.debug("Cover already exists, skipping download")
 
-        self.cover = Tracklist.get_cover_obj(self.cover_path, self.quality)
-        logger.debug(f"Cover obj: {self.cover}")
-
     def format_final_path(self) -> str:
         """Return the final filepath of the downloaded file.
 
@@ -269,7 +312,6 @@ class Track:
         """
         formatter = self.meta.get_formatter()
         logger.debug("Track meta formatter %s", pformat(formatter))
-        # filename = sanitize_filepath(self.file_format.format(**formatter))
         filename = clean_format(self.file_format, formatter)
         self.final_path = (
             os.path.join(self.folder, filename)[:250].strip()
@@ -324,7 +366,7 @@ class Track:
         self,
         album_meta: dict = None,
         cover: Union[Picture, APIC] = None,
-        embed_cover: bool = False,
+        embed_cover: bool = True,
     ):
         """Tag the track using the stored metadata.
 
@@ -336,15 +378,17 @@ class Track:
         :type album_meta: dict
         :param cover: initialized mutagen cover object
         :type cover: Union[Picture, APIC]
+        :param embed_cover: Embed cover art into file
+        :type embed_cover: bool
         """
         assert isinstance(self.meta, TrackMetadata), "meta must be TrackMetadata"
-        if not self._is_downloaded:
+        if not self.downloaded:
             logger.info(
                 "Track %s not tagged because it was not downloaded", self["title"]
             )
             return
 
-        if self._is_tagged:
+        if self.tagged:
             logger.info(
                 "Track %s not tagged because it is already tagged", self["title"]
             )
@@ -357,16 +401,13 @@ class Track:
             self.container = "FLAC"
             logger.debug("Tagging file with %s container", self.container)
             audio = FLAC(self.final_path)
-        elif self.quality == 1:
+        elif self.quality <= 1:
             self.container = "MP3"
             logger.debug("Tagging file with %s container", self.container)
             try:
                 audio = ID3(self.final_path)
             except ID3NoHeaderError:
                 audio = ID3()
-        elif self.quality == 0:  # tidal and deezer
-            # TODO: add compatibility with MP4 container
-            raise NotImplementedError("Qualities < 320kbps not implemented")
         else:
             raise InvalidQuality(f'Invalid quality: "{self.quality}"')
 
@@ -374,20 +415,22 @@ class Track:
         for k, v in self.meta.tags(self.container):
             audio[k] = v
 
-        if cover is None:
-            assert hasattr(self, "cover")
-            cover = self.cover
+        if embed_cover and cover is None:
+            assert hasattr(self, "cover_path")
+            cover = Tracklist.get_cover_obj(self.cover_path, self.quality)
 
         if isinstance(audio, FLAC):
-            audio.add_picture(cover)
+            if embed_cover:
+                audio.add_picture(cover)
             audio.save()
         elif isinstance(audio, ID3):
-            audio.add(cover)
+            if embed_cover:
+                audio.add(cover)
             audio.save(self.final_path, "v2_version=3")
         else:
             raise ValueError(f"Unknown container type: {audio}")
 
-        self._is_tagged = True
+        self.tagged = True
 
     def convert(self, codec: str = "ALAC", **kwargs):
         """Converts the track to another codec.
@@ -406,7 +449,7 @@ class Track:
         :type codec: str
         :param kwargs:
         """
-        if not self._is_downloaded:
+        if not self.downloaded:
             logger.debug("Track not downloaded, skipping conversion")
             click.secho("Track not downloaded, skipping conversion", fg="magenta")
             return
@@ -439,6 +482,13 @@ class Track:
         click.secho(f"Converting {self!s}", fg="blue")
         engine.convert()
 
+    @property
+    def title(self):
+        if hasattr(self, "meta"):
+            return self.meta.title
+        else:
+            raise Exception("Track must be loaded before accessing title")
+
     def get(self, *keys, default=None):
         """Safe get method that allows for layered access.
 
@@ -562,7 +612,7 @@ class Tracklist(list):
         :type quality: int
         :rtype: Union[Picture, APIC]
         """
-        cover_type = {1: APIC, 2: Picture, 3: Picture, 4: Picture}
+        cover_type = {0: APIC, 1: APIC, 2: Picture, 3: Picture, 4: Picture}
 
         cover = cover_type.get(quality)
         if cover is Picture:
@@ -648,7 +698,6 @@ class Album(Tracklist):
         self.bit_depth = None
         self.container = None
 
-        self.folder_format = kwargs.get("album_format", FOLDER_FORMAT)
         for k, v in kwargs.items():
             setattr(self, k, v)
 
@@ -673,6 +722,9 @@ class Album(Tracklist):
 
     @classmethod
     def from_api(cls, resp, client):
+        if client.source == "soundcloud":
+            return Playlist.from_api(resp, client)
+
         info = cls._parse_get_resp(resp, client)
         return cls(client, **info)
 
@@ -685,6 +737,11 @@ class Album(Tracklist):
         :rtype: dict
         """
         if client.source == "qobuz":
+            if resp.get("maximum_sampling_rate", False):
+                sampling_rate = resp["maximum_sampling_rate"] * 1000
+            else:
+                sampling_rate = None
+
             return {
                 "id": resp.get("id"),
                 "title": resp.get("title"),
@@ -699,7 +756,7 @@ class Album(Tracklist):
                     resp.get("maximum_bit_depth"), resp.get("maximum_sampling_rate")
                 ),
                 "bit_depth": resp.get("maximum_bit_depth"),
-                "sampling_rate": resp.get("maximum_sampling_rate") * 1000,
+                "sampling_rate": sampling_rate,
                 "tracktotal": resp.get("tracks_count"),
             }
         elif client.source == "tidal":
@@ -721,13 +778,17 @@ class Album(Tracklist):
                 "tracktotal": resp.get("numberOfTracks"),
             }
         elif client.source == "deezer":
-            logger.debug(pformat(resp))
+            if resp.get("release_date", False):
+                year = resp["release_date"][:4]
+            else:
+                year = None
+
             return {
                 "id": resp.get("id"),
                 "title": resp.get("title"),
                 "_artist": safe_get(resp, "artist", "name"),
                 "albumartist": safe_get(resp, "artist", "name"),
-                "year": str(resp.get("year"))[:4],
+                "year": year,
                 # version not given by API
                 "cover_urls": {
                     sk: resp.get(rk)  # size key, resp key
@@ -784,7 +845,7 @@ class Album(Tracklist):
 
     def download(
         self,
-        quality: int = 7,
+        quality: int = 3,
         parent_folder: Union[str, os.PathLike] = "StreamripDownloads",
         database: MusicDB = None,
         **kwargs,
@@ -803,7 +864,9 @@ class Album(Tracklist):
         :param keep_cover: Keep the cover art image after downloading.
         True by default.
         """
-        folder = self._get_formatted_folder(parent_folder)
+        self.folder_format = kwargs.get("folder_format", FOLDER_FORMAT)
+        quality = min(quality, self.client.max_quality)
+        folder = self._get_formatted_folder(parent_folder, quality)
 
         os.makedirs(folder, exist_ok=True)
         logger.debug("Directory created: %s", folder)
@@ -812,11 +875,13 @@ class Album(Tracklist):
         cover = None
         cover_path = os.path.join(folder, "cover.jpg")
 
+        self.download_message()
+
         if os.path.isfile(cover_path):
             logger.debug("Cover already downloaded: %s. Skipping", cover_path)
         else:
             click.secho("Downloading cover art", fg="magenta")
-            if kwargs.get("large_cover", False):
+            if kwargs.get("large_cover", True):
                 cover_url = self.cover_urls.get("large")
                 if self.client.source == "qobuz":
                     tqdm_download(cover_url.replace("600", "org"), cover_path)
@@ -834,17 +899,21 @@ class Album(Tracklist):
             else:
                 tqdm_download(self.cover_urls["small"], cover_path)
 
-        if self.client.source != "deezer":
+        embed_cover = kwargs.get("embed_cover", True)  # embed by default
+        if self.client.source != "deezer" and embed_cover:
             cover = self.get_cover_obj(cover_path, quality)
 
-        self.download_message()
         for track in self:
             logger.debug("Downloading track to %s", folder)
             track.download(
-                quality, folder, kwargs.get("progress_bar", True), database=database
+                quality,
+                folder,
+                kwargs.get("progress_bar", True),
+                database=database,
+                track_format=kwargs.get("track_format", TRACK_FORMAT),
             )
             if kwargs.get("tag_tracks", True) and self.client.source != "deezer":
-                track.tag(cover=cover)
+                track.tag(cover=cover, embed_cover=embed_cover)
 
         if not kwargs.get("keep_cover", True):
             logger.debug(f"Removing cover at {cover_path}")
@@ -857,29 +926,30 @@ class Album(Tracklist):
         self.downloaded = True
 
     def _get_formatter(self) -> dict:
-        dict_ = dict()
+        fmt = dict()
         for key in ALBUM_KEYS:
             if hasattr(self, key):
-                dict_[key] = getattr(self, key)
+                fmt[key] = getattr(self, key)
             else:
-                dict_[key] = None
+                fmt[key] = None
 
-        dict_["sampling_rate"] /= 1000
-        # 48.0kHz -> 48kHz, 44.1kHz -> 44.1kHz
-        if dict_["sampling_rate"] % 1 == 0.0:
-            dict_["sampling_rate"] = int(dict_["sampling_rate"])
+        if fmt.get("sampling_rate", False):
+            fmt["sampling_rate"] /= 1000
+            # 48.0kHz -> 48kHz, 44.1kHz -> 44.1kHz
+            if fmt["sampling_rate"] % 1 == 0.0:
+                fmt["sampling_rate"] = int(fmt["sampling_rate"])
 
-        return dict_
+        return fmt
 
-    def _get_formatted_folder(self, parent_folder: str) -> str:
-        if self.bit_depth is not None and self.sampling_rate is not None:
-            self.container = "FLAC"
-        elif self.client.source == "qobuz":
-            self.container = "MP3"
-        elif self.client.source == "tidal":
-            self.container = "AAC"
+    def _get_formatted_folder(self, parent_folder: str, quality: int) -> str:
+        if quality >= 2:
+            self.container = 'FLAC'
         else:
-            raise Exception(f"{self.bit_depth}, {self.sampling_rate}")
+            self.bit_depth = self.sampling_rate = None
+            if self.client.source == 'tidal':
+                self.container = 'AAC'
+            else:
+                self.container = 'MP3'
 
         formatted_folder = clean_format(self.folder_format, self._get_formatter())
 
@@ -913,7 +983,7 @@ class Playlist(Tracklist):
     """Represents a downloadable playlist.
 
     Usage:
-    >>> resp = client.get('hip hop', 'playlist')
+    >>> resp = client.search('hip hop', 'playlist')
     >>> pl = Playlist.from_api(resp['items'][0], client)
     >>> pl.load_meta()
     >>> pl.download()
@@ -956,8 +1026,7 @@ class Playlist(Tracklist):
         :type new_tracknumbers: bool
         :param kwargs:
         """
-        self.meta = self.client.get(self.id, "playlist")
-        self.name = self.meta.get("title")
+        self.meta = self.client.get(id=self.id, media_type="playlist")
         self._load_tracks(**kwargs)
 
     def _load_tracks(self, new_tracknumbers: bool = True):
@@ -967,15 +1036,17 @@ class Playlist(Tracklist):
         :type new_tracknumbers: bool
         """
         if self.client.source == "qobuz":
+            self.name = self.meta["name"]
             tracklist = self.meta["tracks"]["items"]
 
-            def gen_cover(track):  # ?
+            def gen_cover(track):
                 return track["album"]["image"]["small"]
 
             def meta_args(track):
                 return {"track": track, "album": track["album"]}
 
         elif self.client.source == "tidal":
+            self.name = self.meta["title"]
             tracklist = self.meta["tracks"]
 
             def gen_cover(track):
@@ -989,42 +1060,53 @@ class Playlist(Tracklist):
                 }
 
         elif self.client.source == "deezer":
+            self.name = self.meta["title"]
             tracklist = self.meta["tracks"]
 
             def gen_cover(track):
                 return track["album"]["cover_medium"]
 
-            def meta_args(track):
-                return {"track": track, "source": self.client.source}
+        elif self.client.source == "soundcloud":
+            self.name = self.meta["title"]
+            tracklist = self.meta["tracks"]
+
+            def gen_cover(track):
+                return track["artwork_url"].replace("large", "t500x500")
 
         else:
             raise NotImplementedError
 
-        for i, track in enumerate(tracklist):
-            # TODO: This should be managed with .m3u files and alike. Arbitrary
-            # tracknumber tags might cause conflicts if the playlist files are
-            # inside of a library folder
-            meta = TrackMetadata(**meta_args(track))
-            if new_tracknumbers:
-                meta["tracknumber"] = str(i + 1)
+        self.tracktotal = len(tracklist)
+        if self.client.source == "soundcloud":
+            # No meta is included in soundcloud playlist
+            # response, so it is loaded at download time
+            for track in tracklist:
+                self.append(Track(self.client, id=track["id"]))
+        else:
+            for track in tracklist:
+                # TODO: This should be managed with .m3u files and alike. Arbitrary
+                # tracknumber tags might cause conflicts if the playlist files are
+                # inside of a library folder
+                meta = TrackMetadata(track=track, source=self.client.source)
 
-            self.append(
-                Track(
-                    self.client,
-                    id=track.get("id"),
-                    meta=meta,
-                    cover_url=gen_cover(track),
+                self.append(
+                    Track(
+                        self.client,
+                        id=track.get("id"),
+                        meta=meta,
+                        cover_url=gen_cover(track),
+                    )
                 )
-            )
 
         logger.debug(f"Loaded {len(self)} tracks from playlist {self.name}")
 
     def download(
         self,
-        parent_folder: str = "Downloads",
-        quality: int = 6,
+        parent_folder: str = "StreamripDownloads",
+        quality: int = 3,
         filters: Callable = None,
         database: MusicDB = None,
+        **kwargs,
     ):
         """Download and tag all of the tracks.
 
@@ -1040,10 +1122,19 @@ class Playlist(Tracklist):
         logger.debug(f"Parent folder {folder}")
 
         self.download_message()
-        for track in self:
-            track.download(parent_folder=folder, quality=quality, database=database)
-            if self.client.source != "deezer":
-                track.tag()
+        for i, track in enumerate(self):
+            if self.client.source == "soundcloud":
+                track.load_meta()
+
+            if kwargs.get("new_tracknumbers", True):
+                track.meta["tracknumber"] = str(i + 1)
+
+            if (
+                track.download(parent_folder=folder, quality=quality, database=database)
+                and self.client.source != "deezer"
+            ):
+
+                track.tag(embed_cover=kwargs.get("embed_cover", True))
 
     @staticmethod
     def _parse_get_resp(item: dict, client: ClientInterface):
@@ -1057,8 +1148,8 @@ class Playlist(Tracklist):
         """
         if client.source == "qobuz":
             return {
-                "name": item.get("name"),
-                "id": item.get("id"),
+                "name": item["name"],
+                "id": item["id"],
             }
         elif client.source == "tidal":
             return {
@@ -1070,9 +1161,21 @@ class Playlist(Tracklist):
                 "name": item["title"],
                 "id": item["id"],
             }
+        elif client.source == "soundcloud":
+            return {
+                "name": item["title"],
+                "id": item["permalink_url"],
+                "description": item["description"],
+                "popularity": f"{item['likes_count']} likes",
+                "tracktotal": len(item["tracks"]),
+            }
 
         raise InvalidSourceError(client.source)
 
+    @property
+    def title(self):
+        return self.name
+
     def __repr__(self) -> str:
         """Return a string representation of this Playlist object.
         Useful for pprint and json.dumps.
@@ -1147,7 +1250,7 @@ class Artist(Tracklist):
 
     def download(
         self,
-        parent_folder: str = "Downloads",
+        parent_folder: str = "StreamripDownloads",
         filters: Optional[Tuple] = None,
         no_repeats: bool = False,
         quality: int = 6,
@@ -1161,38 +1264,34 @@ class Artist(Tracklist):
         :type filters: Optional[Tuple]
         :param no_repeats: Remove repeats
         :type no_repeats: bool
-        :param quality: in (4, 5, 6, 7, 27)
+        :param quality: in (0, 1, 2, 3, 4)
         :type quality: int
         """
         folder = sanitize_filename(self.name)
         folder = os.path.join(parent_folder, folder)
 
         logger.debug("Artist folder: %s", folder)
-
         logger.debug(f"Length of tracklist {len(self)}")
-        if no_repeats:
+        logger.debug(f"Filters: {filters}")
+
+        if 'repeats' in filters:
             final = self._remove_repeats(bit_depth=max, sampling_rate=min)
+            filters = tuple(f for f in filters if f != 'repeats')
         else:
             final = self
 
         if isinstance(filters, tuple) and self.client.source == "qobuz":
-            filters = [getattr(self, filter_) for filter_ in filters]
-            logger.debug("Filters: %s", filters)
-            for filter_ in filters:
-
-                def inter(album):
-                    """Intermediate function to pass self into f"""
-                    return filter_(self, album)
-
-                final = filter(inter, final)
+            filter_funcs = (getattr(self, f"_{filter_}") for filter_ in filters)
+            for func in filter_funcs:
+                final = filter(func, final)
 
         self.download_message()
         for album in final:
-            click.secho(f"Downloading album: {album}", fg="blue")
             try:
                 album.load_meta()
             except NonStreamable:
                 logger.info("Skipping album, not available to stream.")
+                continue
             album.download(
                 parent_folder=folder,
                 quality=quality,
@@ -1220,28 +1319,6 @@ class Artist(Tracklist):
         # equivalent to Artist(client=client, **info)
         return cls(client=client, **info)
 
-    def _remove_repeats(self, bit_depth=max, sampling_rate=max):
-        """Remove the repeated albums from self. May remove different
-        versions of the same album.
-
-        :param bit_depth: either max or min functions
-        :param sampling_rate: either max or min functions
-        """
-        groups = dict()
-        for album in self:
-            if (t := self.essence(album.title)) not in groups:
-                groups[t] = []
-            groups[t].append(album)
-
-        for group in groups.values():
-            assert bit_depth in (min, max) and sampling_rate in (min, max)
-            best_bd = bit_depth(a["bit_depth"] for a in group)
-            best_sr = sampling_rate(a["sampling_rate"] for a in group)
-            for album in group:
-                if album["bit_depth"] == best_bd and album["sampling_rate"] == best_sr:
-                    yield album
-                    break
-
     @staticmethod
     def _parse_get_resp(item: dict, client: ClientInterface):
         """Parse a result from a client.search call.
@@ -1268,11 +1345,30 @@ class Artist(Tracklist):
 
     # ----------- Filters --------------
 
-    @staticmethod
-    def studio_albums(artist, album: Album) -> bool:
-        """Passed as a parameter by the user.
+    def _remove_repeats(self, bit_depth=max, sampling_rate=max):
+        """Remove the repeated albums from self. May remove different
+        versions of the same album.
 
-        >>> artist.download(filters=Artist.studio_albums)
+        :param bit_depth: either max or min functions
+        :param sampling_rate: either max or min functions
+        """
+        groups = dict()
+        for album in self:
+            if (t := self.essence(album.title)) not in groups:
+                groups[t] = []
+            groups[t].append(album)
+
+        for group in groups.values():
+            assert bit_depth in (min, max) and sampling_rate in (min, max)
+            best_bd = bit_depth(a["bit_depth"] for a in group)
+            best_sr = sampling_rate(a["sampling_rate"] for a in group)
+            for album in group:
+                if album["bit_depth"] == best_bd and album["sampling_rate"] == best_sr:
+                    yield album
+                    break
+
+    def _non_studio_albums(self, album: Album) -> bool:
+        """Passed as a parameter by the user.
 
         This will download only studio albums.
 
@@ -1286,12 +1382,9 @@ class Artist(Tracklist):
             and TYPE_REGEXES["extra"].search(album.title) is None
         )
 
-    @staticmethod
-    def no_features(artist, album):
+    def _features(self, album):
         """Passed as a parameter by the user.
 
-        >>> artist.download(filters=Artist.no_features)
-
         This will download only albums where the requested
         artist is the album artist.
 
@@ -1300,14 +1393,11 @@ class Artist(Tracklist):
         :type album: Album
         :rtype: bool
         """
-        return artist["name"] == album["albumartist"]
+        return self["name"] == album["albumartist"]
 
-    @staticmethod
-    def no_extras(artist, album):
+    def _extras(self, album):
         """Passed as a parameter by the user.
 
-        >>> artist.download(filters=Artist.no_extras)
-
         This will skip any extras.
 
         :param artist: usually self
@@ -1317,12 +1407,9 @@ class Artist(Tracklist):
         """
         return TYPE_REGEXES["extra"].search(album.title) is None
 
-    @staticmethod
-    def remaster_only(artist, album):
+    def _non_remasters(self, album):
         """Passed as a parameter by the user.
 
-        >>> artist.download(filters=Artist.remaster_only)
-
         This will download only remasterd albums.
 
         :param artist: usually self
@@ -1332,12 +1419,9 @@ class Artist(Tracklist):
         """
         return TYPE_REGEXES["remaster"].search(album.title) is not None
 
-    @staticmethod
-    def albums_only(artist, album):
+    def _non_albums(self, album):
         """This will ignore non-album releases.
 
-        >>> artist.download(filters=(albums_only))
-
         :param artist: usually self
         :param album: the album to check
         :type album: Album
