@@ -1,7 +1,6 @@
 import json
 import logging
 import re
-import sys
 from typing import Generator, Optional, Tuple, Union
 
 from .constants import (
@@ -39,6 +38,7 @@ class TrackMetadata:
         * cover
         * tracknumber
         * discnumber
+        * tracktotal
 
     """
 
@@ -113,9 +113,10 @@ class TrackMetadata:
             self.date = resp.get("release_date")
             self.albumartist = resp.get("artist", {}).get("name")
             self.label = resp.get("label")
-
+        elif self.__source == "soundcloud":
+            raise Exception
         else:
-            raise ValueError
+            raise ValueError(self.__source)
 
     def add_track_meta(self, track: dict):
         """Parse the metadata from a track dict returned by the
@@ -150,15 +151,25 @@ class TrackMetadata:
             self.discnumber = track.get("disk_number")
             self.artist = track.get("artist", {}).get("name")
 
+        elif self.__source == "soundcloud":
+            self.title = track["title"].strip()
+            self.genre = track["genre"]
+            self.artist = track["user"]["username"]
+            self.albumartist = self.artist
+            self.year = track["created_at"][:4]
+            self.label = track["label_name"]
+            self.description = track["description"]
+            self.tracknumber = 0
+            self.tracktotal = 0
+
         else:
-            raise ValueError
+            raise ValueError(self.__source)
 
         if track.get("album"):
             self.add_album_meta(track["album"])
 
     def _mod_title(self, version, work):
         if version is not None:
-            logger.debug("Version found: %s", version)
             self.title = f"{self.title} ({version})"
         if work is not None:
             logger.debug("Work found: %s", work)
@@ -329,7 +340,7 @@ class TrackMetadata:
             else:
                 text = getattr(self, k)
 
-            if text is not None:
+            if text is not None and v is not None:
                 yield (v.__name__, v(encoding=3, text=text))
 
     def __mp4_tags(self) -> Tuple[str, str]:
